.. include:: ./README.md
   :parser: myst_parser.sphinx_

.. toctree::
   :hidden:

   getting-started/index
   develop/index
   cookbooks/index
   deploy/index
   cloud/index
   knowledge-base/index
   changelog

-----